@@ -4,45 +4,27 @@ use strict;
 use warnings;
 use warnings  qw(FATAL utf8); # Fatalize encoding glitches.
 
+our $VERSION = '2.51';
+
 use GraphViz2;
-
 use Moo;
-
 use Parse::RecDescent;
 
 has graph =>
 (
-	default  => sub{return ''},
+	default  => sub {
+		GraphViz2->new(
+			edge   => {color => 'grey'},
+			global => {directed => 1},
+			graph  => {rankdir => 'TB'},
+			node   => {color => 'blue', shape => 'oval'},
+		)
+        },
 	is       => 'rw',
 	#isa     => 'GraphViz2',
 	required => 0,
 );
 
-our $VERSION = '2.50';
-
-# -----------------------------------------------
-
-sub BUILD
-{
-	my($self) = @_;
-
-	$self -> graph
-	(
-		$self -> graph ||
-		GraphViz2 -> new
-		(
-			edge   => {color => 'grey'},
-			global => {directed => 1},
-			graph  => {rankdir => 'TB'},
-			logger => '',
-			node   => {color => 'blue', shape => 'oval'},
-		)
-	);
-
-} # End of BUILD.
-
-# -----------------------------------------------
-
 sub create
 {
 	my($self, %arg) = @_;
@@ -159,32 +141,15 @@ L<GraphViz2::Parse::RecDescent> - Visualize a Parse::RecDescent grammar as a gra
 	use GraphViz2;
 	use GraphViz2::Parse::RecDescent;
 
-	use Log::Handler;
-
 	use Parse::RecDescent;
 
 	use File::Slurp; # For read_file().
 
-	# ------------------------------------------------
-
-	my($logger) = Log::Handler -> new;
-
-	$logger -> add
-		(
-		 screen =>
-		 {
-			 maxlevel       => 'debug',
-			 message_layout => '%m',
-			 minlevel       => 'error',
-		 }
-		);
-
 	my($graph) = GraphViz2 -> new
 		(
 		 edge   => {color => 'grey'},
 		 global => {directed => 1},
 		 graph  => {rankdir => 'TB'},
-		 logger => $logger,
 		 node   => {color => 'blue', shape => 'oval'},
 		);
 	my($g)      = GraphViz2::Parse::RecDescent -> new(graph => $graph);
@@ -224,8 +189,7 @@ Key-value pairs accepted in the parameter list:
 
 This option specifies the GraphViz2 object to use. This allows you to configure it as desired.
 
-The default is GraphViz2 -> new. The default attributes are the same as in the synopsis, above,
-except for the logger of course, which defaults to ''.
+The default is GraphViz2->new. The default attributes are the same as in the synopsis, above.
 
 This key is optional.
 
